======
DIISCO
======


.. image:: https://img.shields.io/pypi/v/diisco.svg
        :target: https://pypi.python.org/pypi/diisco

A probabilistic programming method to characterize dynamic cellular interactions in longitudinal scRNA-seq data.


* Free software: MIT license



